View source: R/occCite_plotting.R
| plot.occCiteData | R Documentation |
Generates up to three different kinds of plots, with toggles determining whether plots should be done for individual species or aggregating all species–histogram by year of occurrence records, waffle plot of primary data sources, waffle plot of data aggregators.
## S3 method for class 'occCiteData'
plot(x, ...)
x |
An object of class |
... |
Additional arguments affecting how the formatted citation document is produced. 'bySpecies': Logical; setting to 'TRUE' generates the desired plots for each species. 'plotTypes': The type of plot to be generated; "yearHistogram", "source", and/or "aggregator". |
A list containing the desired plots.
plot(x = myOccCiteObject,
bySpecies = FALSE,
plotTypes = c("yearHistogram"))
## Not run:
# Requires the 'waffle' package from GitHub
plot(x = myOccCiteObject,
bySpecies = FALSE,
plotTypes = c("yearHistogram", "source", "aggregator"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.